Welcom to ``ibm-wmla``
=======================

``ibm-wmla`` is a Python library that allows to work with IBM Watson Machine Learning Accelerator.

`IBM Watson Machine Learning Accelerator Inference APIs`_

.. _IBM Watson Machine Learning Accelerator Inference APIs: https://www.ibm.com/docs/en/wmla/2.3?topic=workload-inference

